@@ -1,6 +1,6 @@
 package EWS::Calendar::Role::RetrieveWithinWindow;
 BEGIN {
-  $EWS::Calendar::Role::RetrieveWithinWindow::VERSION = '1.131710_001';
+  $EWS::Calendar::Role::RetrieveWithinWindow::VERSION = '1.103530';
 }
 use Moose::Role;
 
@@ -15,13 +15,11 @@ sub _list_messages {
 }
 
 sub _check_for_errors {
-    my ($self, $kind, $response, $opts) = @_;
+    my ($self, $kind, $response) = @_;
 
-    croak "Fault returned from Exchange Server: ($opts->{impersonate}) $response->{Fault}->{faultstring}\n"
-        if ( exists $response->{Fault} );
     foreach my $msg ( $self->_list_messages($kind, $response) ) {
         my $code = $msg->{"${kind}ResponseMessage"}->{ResponseCode} || '';
-        croak "Fault returned from Exchange Server: ($opts->{impersonate}) $code\n"
+        croak "Fault returned from Exchange Server: $code\n"
             if $code ne 'NoError';
     }
 }
@@ -39,19 +37,9 @@ sub _list_calendaritems {
 # Find list of items within the view, then Get details for each one
 # (item:Body is only available this way, it's not returned by FindItem)
 sub retrieve_within_window {
-    my ($self, $opts) = @_;
+    my ($self, $query) = @_;
 
     my $find_response = scalar $self->client->FindItem->(
-        (exists $opts->{impersonate} ? (
-            Impersonation => {
-                ConnectingSID => {
-                    PrimarySmtpAddress => $opts->{impersonate},
-                }
-            },
-        ) : ()),
-        RequestVersion => {
-            Version => $self->client->server_version,
-        },
         Traversal => 'Shallow',
         ItemShape => {
             BaseShape => 'IdOnly',
@@ -66,12 +54,12 @@ sub retrieve_within_window {
             ],
         },
         CalendarView => {
-            StartDate => $opts->{window}->start->iso8601,
-            EndDate   => $opts->{window}->end->iso8601,
+            StartDate => $query->start->iso8601,
+            EndDate   => $query->end->iso8601,
         },
     );
 
-    $self->_check_for_errors('FindItem', $find_response, $opts);
+    $self->_check_for_errors('FindItem', $find_response);
 
     my @ids = map { $_->{ItemId}->{Id} }
                   $self->_list_calendaritems('FindItem', $find_response);
@@ -80,16 +68,6 @@ sub retrieve_within_window {
         if scalar @ids == 0;
 
     my $get_response = scalar $self->client->GetItem->(
-        (exists $opts->{impersonate} ? (
-            Impersonation => {
-                ConnectingSID => {
-                    PrimarySmtpAddress => $opts->{impersonate},
-                }
-            },
-        ) : ()),
-        RequestVersion => {
-            Version => $self->client->server_version,
-        },
         ItemShape => {
             BaseShape => 'IdOnly',
             AdditionalProperties => {
@@ -112,10 +90,6 @@ sub retrieve_within_window {
                         calendar:LegacyFreeBusyStatus
                         item:IsDraft
                         item:Body
-                        calendar:OptionalAttendees
-                        calendar:RequiredAttendees
-                        calendar:Duration
-                        calendar:UID
                     /,
                 ],
             },
@@ -129,7 +103,7 @@ sub retrieve_within_window {
         },
     );
 
-    $self->_check_for_errors('GetItem', $get_response, $opts);
+    $self->_check_for_errors('GetItem', $get_response);
 
     return EWS::Calendar::ResultSet->new({
         items => [ $self->_list_calendaritems('GetItem', $get_response) ]
