@@ -1,6 +1,6 @@
 package EWS::Client::Calendar;
 BEGIN {
-  $EWS::Client::Calendar::VERSION = '1.131710_001';
+  $EWS::Client::Calendar::VERSION = '1.103530';
 }
 use Moose;
 
@@ -18,11 +18,7 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
-# ABSTRACT: Calendar Entries from Microsoft Exchange Server
-
-
 __END__
-=pod
 
 =head1 NAME
 
@@ -30,7 +26,7 @@ EWS::Client::Calendar - Calendar Entries from Microsoft Exchange Server
 
 =head1 VERSION
 
-version 1.131710_001
+version 1.103530
 
 =head1 SYNOPSIS
 
@@ -108,13 +104,6 @@ returned results.
 Entries with a start date before this timestamp will be included in the
 results.
 
-=item C<impersonate> => String (optional)
-
-Passing the primary SMTP address of another account will retrieve the entries
-for that Exchange user instead, assuming you have sufficient rights to
-I<Impersonate> that account. If you do not have rights, an error will be
-thrown.
-
 =back
 
 The returned object contains the collection of calendar entries which matched
@@ -333,14 +322,13 @@ want to help out.
 
 =head1 AUTHOR
 
-Oliver Gorwits <oliver@cpan.org>
+Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT & LICENSE
 
-This software is copyright (c) 2013 by University of Oxford.
+Copyright (c) University of Oxford 2010.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
+=cut
\ No newline at end of file
