@@ -1,6 +1,6 @@
 package EWS::Client::Contacts;
 BEGIN {
-  $EWS::Client::Contacts::VERSION = '1.131710_001';
+  $EWS::Client::Contacts::VERSION = '1.103530';
 }
 use Moose;
 
@@ -18,11 +18,7 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
-# ABSTRACT: Contact Entries from Microsoft Exchange Server
-
-
 __END__
-=pod
 
 =head1 NAME
 
@@ -30,7 +26,7 @@ EWS::Client::Contacts - Contact Entries from Microsoft Exchange Server
 
 =head1 VERSION
 
-version 1.131710_001
+version 1.103530
 
 =head1 SYNOPSIS
 
@@ -87,31 +83,24 @@ reference.
 
 =head2 $contacts->retrieve( \%arguments )
 
-Query the Exchange server and retrieve contact entries. By default the
-C<retrieve()> method will return contacts for the account under which you
-authenticated to the Exchange server (that is, the credentials passed to the
-L<EWS::Client> constructor). The following arguments will change this
-behaviour:
+Query the Exchange server and retrieve contact entries. Pass the following
+arguments in a hash ref:
 
 =over 4
 
 =item C<email> => String (optional)
 
+By default the C<retrieve()> method will return contacts for the account under
+which you authenticated to the Exchange server (that is, the credentials
+passed to the L<EWS::Client> constructor).
+
 Passing the primary SMTP address of another account will retrieve the contacts
-for that Exchange user instead using the I<Delegation> feature, assuming you
-have rights to see their contacts (i.e. the user has shared their contacts).
-If you do not have rights, an error will be thrown.
+for that Exchange user instead, assuming you have rights to see their
+contacts. If you do not have rights, an error will be thrown.
 
 If you pass one of the account's secondary SMTP addresses this module
 I<should> be able to divine the primary SMTP address required.
 
-=item C<impersonate> => String (optional)
-
-Passing the primary SMTP address of another account will retrieve the contacts
-for that Exchange user instead, assuming you have sufficient rights to
-I<Impersonate> that account. If you do not have rights, an error will be
-thrown.
-
 =back
 
 The returned object contains the collection of contact entries and is of type
@@ -162,18 +151,6 @@ server query. They are each objects of type C<EWS::Contacts::Item>.
 The field you should use to describe this entry, being probably the person or
 business's name.
 
-=head2 $item->JobTitle
-
-The Job Title field of the contact.
-
-=head2 $item->CompanyName
-
-The Comany Name field of the contact.
-
-=head2 $item->BusinessHomePage
-
-The Business Home Page field within the contact.
-
 =head2 $item->PhoneNumbers
 
 This property comprises all the phone numbers associated with the contact.
@@ -183,15 +160,9 @@ types, such as Mobile Phone, Business Line, and so on. Each of these may in
 turn store a free text field so people often put multiple numbers in,
 separated by a delimiter.
 
-As a result of this freedom, this module makes no effort to interpret the
-content of the number fields, only to retrieve them. It's assumed you are
-familiar with your own number storage conventions, or can use a module such
-as L<Number::Phone::Normalize> to parse the result.
-
 In this property you'll find a hash ref of all this data, with keys being the
-number types (Mobile Phone, etc), and values being array refs of I<data>. As
-explained above, the data might be single numbers or free text with several
-telephone numbers that you will need to parse yourself. For example:
+number types (Mobile Phone, etc), and values being array refs of numbers. The
+module splits up number lists but preserves their order. For example:
 
  my $numbers = $entry->PhoneNumbers;
  
@@ -205,26 +176,18 @@ telephone numbers that you will need to parse yourself. For example:
  
  # might print something like:
  
- Mobile Phone : 73244
- Business Line : 88888
+ Oliver Gorwits : 73244
+ John Smith : 88888
 
-=head2 $item->EmailAddresses
+In the future this format may change, or may migrate into an object based
+storage.
 
-This property comprises all the email addresses associated with the contact.
+=head1 TODO
 
-Similar to the C<PhoneNumbers> property, this is a hash ref of all data, with
-keys being the email address type and values being array refs of I<data>.
+There should be more properties imported than just the DisplayName and
+PhoneNumbers.
 
-See C<PhoneNumbers>, above for an example of how to process this property.
-
-=head2 $item->PhysicalAddresses
-
-This property comprises all the physical addresses associated with the
-contact.
-
-Again, like the C<PhoneNumbers> and C<EmailAddresses> properties, this is a
-hash ref of array refs, where the hash keys are address identifiers, and the
-values are lists of addresses.
+PhoneNumbers will maybe migrate into some kind of object based storage.
 
 =head1 SEE ALSO
 
@@ -236,14 +199,13 @@ values are lists of addresses.
 
 =head1 AUTHOR
 
-Oliver Gorwits <oliver@cpan.org>
+Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT & LICENSE
 
-This software is copyright (c) 2013 by University of Oxford.
+Copyright (c) University of Oxford 2010.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
+=cut
\ No newline at end of file
