@@ -1,6 +1,6 @@
 package EWS::Contacts::Role::Reader;
 BEGIN {
-  $EWS::Contacts::Role::Reader::VERSION = '1.131710_001';
+  $EWS::Contacts::Role::Reader::VERSION = '1.103530';
 }
 use Moose::Role;
 
@@ -36,30 +36,16 @@ sub _list_contactitems {
 }
 
 sub _get_contacts {
-    my ($self, $opts) = @_;
+    my ($self, @account_id) = @_;
 
     return scalar $self->client->FindItem->(
-        (exists $opts->{impersonate} ? (
-            Impersonation => {
-                ConnectingSID => {
-                    PrimarySmtpAddress => $opts->{impersonate},
-                }
-            },
-        ) : ()),
-        RequestVersion => {
-            Version => $self->client->server_version,
-        },
         ItemShape => { BaseShape => 'AllProperties' },
         ParentFolderIds => {
             cho_FolderId => [
                 { DistinguishedFolderId =>
                     {
                         Id => 'contacts',
-                        (exists $opts->{email} ? (
-                            Mailbox => {
-                                EmailAddress => $opts->{email},
-                            },
-                        ) : ()), # optional
+                        @account_id, # optional
                     }
                 }
             ]
@@ -73,15 +59,14 @@ sub _get_contacts {
 sub retrieve {
     my ($self, $opts) = @_;
 
-    my $get_response = $self->_get_contacts($opts);
+    my $get_response = $self->_get_contacts(
+        (exists $opts->{email} ? (Mailbox => { EmailAddress => $opts->{email} }) : ())
+    );
 
     if (exists $get_response->{'ResponseCode'} and defined $get_response->{'ResponseCode'}
         and $get_response->{'ResponseCode'} eq 'ErrorNonPrimarySmtpAddress') {
 
-        $self->retrieve({
-            %$opts,
-            email => $get_response->{'MessageXml'}->{'Value'}->{'_'},
-        });
+        $self->retrieve({email => $get_response->{'MessageXml'}->{'Value'}->{'_'}});
     }
 
     $self->_check_for_errors('FindItem', $get_response);
